\name{GSTiCluster}
\alias{GSTiCluster}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Integrative multi-omics clustering for disease subtype discovery by sparse overlapping group lasso and tight clustering
}
\description{
GST-iCluster fits a latent variable model of integrative clustering to accommodate the information of inter-omics regulation flows, and to exclude outlier samples scattering away from the tight clusters.
}
\usage{
GSTiCluster(datasets, k, Best_lam = NULL, max.iter = 100, is.scale = FALSE, f.module,
is.tight = FALSE, lambda_1 = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{datasets}{
Input variable matrix (combined multi-omics datasets by samples)
}
  \item{k}{
# of integrative clusters
}
  \item{Best_lam}{
Regularization parameter for sparse overlapping group lasso
}
  \item{max.iter}{
# of maximum iteration of EM
}
  \item{is.scale}{
Logical value indicating whether data are scaled and centered
}
  \item{f.module}{
Input feature module matrix (Row: feature module / Col: feature)
}
  \item{is.tight}{
Logical value indicating whether tight clustering is performed
}
  \item{lambda_1}{
Regularization parameter for tight clustering
}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
}
\value{
Beta = Estimated sparse coefficient matrix  \cr
Z = Estimated average latent variable matrix \cr
cluster = Integrative clustering label of samples  \cr
is.sample.penalized = Logical values whether samples are included  \cr
tight.cluster = Integrative tight clustering label of samples \cr
}
\references{

}
\author{
SungWhan Kim \email{suk73@pitt.edu}
}
\note{
%%  ~~further notes~~
}
%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
set.seed(123)
library(doMC) 
library(pamr)

# Generate two random omics datasets
mu <- c(-3,1,3)
Simul_mRNA <- rbind(cbind(matrix(rnorm(  40 * 5 , mu[1] , 0.1), 40 , 5) ,
              matrix(rnorm(  40 * 5 , mu[2] , 0.1), 40 , 5) ,
              matrix(rnorm(  40 * 5 , mu[3] , 0.1), 40 , 5)
              ),
              matrix(rnorm(  10 * 15 , 0 , 0.1), 10 , 15))


mu <- c(1,3,-3)
Simul_methyl <- rbind(cbind(matrix(rnorm(  40 * 5 , mu[1] , 0.1), 40 , 5) ,
                            matrix(rnorm(  40 * 5 , mu[2] , 0.1), 40 , 5) ,
                            matrix(rnorm(  40 * 5 , mu[3] , 0.1), 40 , 5)),
                      matrix(rnorm(  10 * 15 , 0 , 0.1), 10 , 15))

# feature modules across two datasets
null_gr <- rep(0,100); null_gr[ c(1:10, 51:60)] <- 1 ; Group_1 <- null_gr
null_gr <- rep(0,100); null_gr[ c(11:20, 61:70)] <- 1 ; Group_2 <- null_gr
null_gr <- rep(0,100); null_gr[ c(21:30, 71:80)] <- 1 ; Group_3 <- null_gr
null_gr <- rep(0,100); null_gr[ c(31:40, 81:90)] <- 1 ; Group_4 <- null_gr

# Singleton_group
Group_Single <- matrix(0,20,100)
Group_Single[1:10,41:50] <- diag(10)
Group_Single[11:20,91:100] <- diag(10)

# Total feature module
Total_group <- rbind(Group_1, Group_2, Group_3, Group_4, Group_Single)

# Combined dataset
DList <- rbind(Simul_mRNA, Simul_methyl)

## Example of GS-iCluster
GSTiCluster(DList, k = 3, Best_lam = 5, f.module = Total_group, is.scale=TRUE)

# Combined dataset (including non-informative samples)
## Three non-informative samples
Dat.r.sam <- matrix(rnorm(  dim(DList)[1]*3 , 0 , 0.01), dim(DList)[1], 3) 
DDList <- cbind(DList, Dat.r.sam) # dataset combined with three non-informative samples

## Example of GST-iCluster
GSTiCluster(DDList, k = 3, Best_lam = 10, f.module = Total_group, is.scale=TRUE, 
is.tight = TRUE, lambda_1 = 1)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ GST-iCluster }

